set an_xml_document "<quotations>
<onequote>
  <quotation_id>1</quotation_id>
  <insertion_date>1999-02-04</insertion_date>
  <author_name>Bill Gates</author_name>
  <category>Computer Industry Punditry</category>
  <quote>640K ought to be enough for anybody.</quote>
</onequote>
</quotations>
"

# return the string with a status code of 200 (normal)
# and a MIME type of "application/xml" (the preferred XML
# mime type)

ns_return 200 application/xml $an_xml_document
