# this page will expire two cookies on a user's browser, regardless
# of whether they are actually set

# see http://home.netscape.com/newsref/std/cookie_spec.html
# for full documentation of the Magic Cookie protocol

ns_write "HTTP/1.0 200 OK
MIME-Version: 1.0
Content-Type: text/html
Set-Cookie:  for_today=irrelevant; path=/; expires=Mon, 01-Jan-1990 01:00:00 GMT
Set-Cookie:  for_the_ages=irrelevant; path=/; expires=Mon, 01-Jan-1990 01:00:00 GMT

<html>
<head>
<title>We Expired You</title>
</head>

<body bgcolor=#ffffff text=#000000>
<h2>We Expired You</h2>

<hr>

We expired your two cookies, whether they needed it or not.  

<p>Visit <a
href=\"check-cookies.tcl\">check-cookies.tcl</a> to see what your
browser is in fact now sending to the server, as part of the HTTP
request.


<hr>
<a href=\"http://photo.net/philg/\"><address>philg@mit.edu</address></a>
</body>
</html>
"
