# this page looks the entire cookie header and prints it out

# note that the only interesting action is when we use
# ns_conn headers to get the HTTP headers from AOLserver
# (as an ns_set data structure) then [ns_set get ...] to 
# retrieve the Cookie element

ns_return 200 text/html "<html>
<head>
<title>Checking Cookies</title>
</head>

<body bgcolor=#ffffff text=#000000>
<h2>Checking Cookies</h2>
<hr>

Here's the cookie header that came with this request:
<blockquote>
<code>
[ns_set get [ns_conn headers] Cookie]
</code>
</blockquote>


If you want to play around some more with cookies, here are things
that you can do:

<ul>
<li><a href=\"set-cookies.tcl\">set</a>
<li><a href=\"expire-cookies.tcl\">expire</a>
</ul>

<hr>
<a href=\"http://photo.net/philg/\"><address>philg@mit.edu</address></a>
</body>
</html>"
